@@ -239,7 +239,7 @@ class WavefrontDirectClient(connection_handler.ConnectionHandler,
             self._closed = True
             if self._timer is not None:
                 self._timer.cancel()
-        self._sdk_metrics_registry.close()
+        self._sdk_metrics_registry.close(timeout_secs=1)
 
     # pylint: disable=too-many-arguments
 
@@ -429,8 +429,10 @@ class WavefrontDirectClient(connection_handler.ConnectionHandler,
 
     def get_failure_count(self):
         """Get failure count for one connection."""
-        return (self._points_report_errors + self._histograms_report_errors +
-                self._spans_report_errors + self._span_logs_report_errors)
+        return (self._points_report_errors.count() +
+                self._histograms_report_errors.count() +
+                self._spans_report_errors.count() +
+                self._span_logs_report_errors.count())
 
 
 def remaining_capacity_getter(buf):
